==> 1.0.2.tar.gz: lib/flutter_animated_progress.dart <==
library flutter_animated_progress;

import 'package:flutter/material.dart';

class AnimatedLinearProgressIndicator extends ProgressIndicator {
  const AnimatedLinearProgressIndicator({
    double? value,
    Color? backgroundColor,
    Color? color,
    Animation<Color?>? valueColor,
    this.minHeight,
    String? semanticsLabel,
    String? semanticsValue,
    this.animationDuration=const Duration(milliseconds: 500),
  }) : assert(minHeight == null || minHeight > 0),
        super(
        value: value,
        backgroundColor: backgroundColor,
        color: color,
        valueColor: valueColor,
        semanticsLabel: semanticsLabel,
        semanticsValue: semanticsValue,
      );



  /// {@template flutter.material.LinearProgressIndicator.trackColor}
  /// Color of the track being filled by the linear indicator.
  ///
  /// If [AnimatedLinearProgressIndicator.backgroundColor] is null then the
  /// ambient [AnimatedLinearProgressIndicator.linearTrackColor] will be used.
  /// If that is null, then the ambient theme's [ColorScheme.background]
  /// will be used to draw the track.
  /// {@endtemplate}
  @override
  Color? get backgroundColor => super.backgroundColor;

  /// {@template flutter.material.LinearProgressIndicator.minHeight}
  /// The minimum height of the line used to draw the linear indicator.
  ///
  /// If [AnimatedLinearProgressIndicator.minHeight] is null then it will use the
  /// ambient [AnimatedLinearProgressIndicator.linearMinHeight]. If that is null
  /// it will use 4dp.
  /// {@endtemplate}
  final double? minHeight;


  /// The animation duration for the progress.
  /// If animationDuration is null then it will use the default Duration(milliseconds: 500).
  final Duration? animationDuration;



  @override
  _AnimatedLinearProgressIndicatorState createState() => _AnimatedLinearProgressIndicatorState();
}

class _AnimatedLinearProgressIndicatorState extends State<AnimatedLinearProgressIndicator> with TickerProviderStateMixin  {

  AnimationController? _controller;
  Tween<double>? _tween;
  Animation<double>? _animation;

  void _setControllers(){
    _controller = AnimationController(
      duration: widget.animationDuration,
      vsync: this,
    );

    _tween = Tween(begin: widget.value, end: widget.value);
    _animation = _tween?.animate(
      CurvedAnimation(
        curve: Curves.easeInOut,
        parent: _controller!,
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    _setControllers();
  }
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: _animation!,
        builder: (context, child)
        {
          return LinearProgressIndicator(
            key: widget.key,
            value: _animation?.value,
            backgroundColor: widget.backgroundColor,
            color: widget.color,
            valueColor: widget.valueColor,
            minHeight: widget.minHeight,
            semanticsLabel: widget.semanticsLabel,
            semanticsValue: widget.semanticsValue,
          );
        });

  }

  @override
  void didUpdateWidget(AnimatedLinearProgressIndicator oldWidget) {
    super.didUpdateWidget(oldWidget);
    if(oldWidget.animationDuration!=widget.animationDuration){
      //print("duration is changed remaking the controller and tween");
      _setControllers();
    }
    //print(" old value ${_tween?.begin }  new value ${oldWidget.value},old end ${_tween?.end},animationValue ${_animation?.value}");
    _tween?.begin = _animation?.value;
    _controller?.reset();
    _tween?.end = widget.value;
    _controller?.forward();
  }

  @override
  dispose() {
    _controller?.dispose(); // you need this
    super.dispose();
  }
}

class AnimatedCircularProgressIndicator extends ProgressIndicator {
  const AnimatedCircularProgressIndicator({
    double? value,
    Color? backgroundColor,
    Color? color,
    Animation<Color?>? valueColor,
    String? semanticsLabel,
    this.strokeWidth = 4.0,
    String? semanticsValue,
    this.animationDuration=const Duration(milliseconds: 500),
  }) :super(
    value: value,
    backgroundColor: backgroundColor,
    color: color,
    valueColor: valueColor,
    semanticsLabel: semanticsLabel,
    semanticsValue: semanticsValue,
  );

  /// The animation duration for the progress.
  /// If animationDuration is null then it will use the default Duration(milliseconds: 500).
  final Duration? animationDuration;

  /// The width of the line used to draw the circle.
  final double strokeWidth;


  @override
  _AnimatedCircularProgressIndicatorState createState() => _AnimatedCircularProgressIndicatorState();
}

class _AnimatedCircularProgressIndicatorState extends State<AnimatedCircularProgressIndicator> with TickerProviderStateMixin  {

  AnimationController? _controller;
  Tween<double>? _tween;
  Animation<double>? _animation;

  void _setControllers(){
    _controller = AnimationController(
      duration: widget.animationDuration,
      vsync: this,
    );

    _tween = Tween(begin: widget.value, end: widget.value);
    _animation = _tween?.animate(
      CurvedAnimation(
        curve: Curves.easeInOut,
        parent: _controller!,
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    _setControllers();
  }
  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: _animation!,
        builder: (context, child)
        {
          return CircularProgressIndicator(
            key: widget.key,
            value: _animation?.value,
            backgroundColor: widget.backgroundColor,
            color: widget.color,
            strokeWidth: widget.strokeWidth,
            valueColor: widget.valueColor,
            semanticsLabel: widget.semanticsLabel,
            semanticsValue: widget.semanticsValue,
          );
        });

  }

  @override
  void didUpdateWidget(AnimatedCircularProgressIndicator oldWidget) {
    super.didUpdateWidget(oldWidget);
    if(oldWidget.animationDuration!=widget.animationDuration){
      //print("duration is changed remaking the controller and tween");
      _setControllers();
    }
    //print(" old value ${_tween?.begin }  new value ${oldWidget.value},old end ${_tween?.end},animationValue ${_animation?.value}");
    _tween?.begin = _animation?.value;
    _controller?.reset();
    _tween?.end = widget.value;
    _controller?.forward();
  }

  @override
  dispose() {
    _controller?.dispose(); // you need this
    super.dispose();
  }
}

==> 1.0.4.tar.gz: lib/flutter_animated_progress.dart <==
library flutter_animated_progress;

import 'package:flutter/material.dart';

class AnimatedLinearProgressIndicator extends ProgressIndicator {
  const AnimatedLinearProgressIndicator({
    double? value,
    Color? backgroundColor,
    Color? color,
    Animation<Color?>? valueColor,
    this.minHeight,
    String? semanticsLabel,
    String? semanticsValue,
    this.animationDuration = const Duration(milliseconds: 500),
  })  : assert(minHeight == null || minHeight > 0),
        super(
          value: value,
          backgroundColor: backgroundColor,
          color: color,
          valueColor: valueColor,
          semanticsLabel: semanticsLabel,
          semanticsValue: semanticsValue,
        );

  /// {@template flutter.material.LinearProgressIndicator.trackColor}
  /// Color of the track being filled by the linear indicator.
  ///
  /// If [AnimatedLinearProgressIndicator.backgroundColor] is null then the
  /// ambient [AnimatedLinearProgressIndicator.linearTrackColor] will be used.
  /// If that is null, then the ambient theme's [ColorScheme.background]
  /// will be used to draw the track.
  /// {@endtemplate}
  @override
  Color? get backgroundColor => super.backgroundColor;

  /// {@template flutter.material.LinearProgressIndicator.minHeight}
  /// The minimum height of the line used to draw the linear indicator.
  ///
  /// If [AnimatedLinearProgressIndicator.minHeight] is null then it will use the
  /// ambient [AnimatedLinearProgressIndicator.linearMinHeight]. If that is null
  /// it will use 4dp.
  /// {@endtemplate}
  final double? minHeight;

  /// The animation duration for the progress.
  /// If animationDuration is null then it will use the default Duration(milliseconds: 500).
  final Duration? animationDuration;

  @override
  _AnimatedLinearProgressIndicatorState createState() =>
      _AnimatedLinearProgressIndicatorState();
}

class _AnimatedLinearProgressIndicatorState
    extends State<AnimatedLinearProgressIndicator>
    with TickerProviderStateMixin {
  AnimationController? _controller;
  Tween<double>? _tween;
  Animation<double>? _animation;

  void _setControllers() {
    _controller = AnimationController(
      duration: widget.animationDuration,
      vsync: this,
    );

    _tween = Tween(begin: widget.value, end: widget.value);
    _animation = _tween?.animate(
      CurvedAnimation(
        curve: Curves.easeInOut,
        parent: _controller!,
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    _setControllers();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: _animation!,
        builder: (context, child) {
          return LinearProgressIndicator(
            key: widget.key,
            value: _animation?.value,
            backgroundColor: widget.backgroundColor,
            color: widget.color,
            valueColor: widget.valueColor,
            minHeight: widget.minHeight,
            semanticsLabel: widget.semanticsLabel,
            semanticsValue: widget.semanticsValue,
          );
        });
  }

  @override
  void didUpdateWidget(AnimatedLinearProgressIndicator oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.animationDuration != widget.animationDuration) {
      //print("duration is changed remaking the controller and tween");
      _setControllers();
    }
    //print(" old value ${_tween?.begin }  new value ${oldWidget.value},old end ${_tween?.end},animationValue ${_animation?.value}");
    _tween?.begin = _animation?.value;
    _controller?.reset();
    _tween?.end = widget.value;
    _controller?.forward();
  }

  @override
  dispose() {
    _controller?.dispose(); // you need this
    super.dispose();
  }
}

class AnimatedCircularProgressIndicator extends ProgressIndicator {
  const AnimatedCircularProgressIndicator({
    double? value,
    Color? backgroundColor,
    Color? color,
    Animation<Color?>? valueColor,
    String? semanticsLabel,
    this.strokeWidth = 4.0,
    String? semanticsValue,
    this.animationDuration = const Duration(milliseconds: 500),
  }) : super(
          value: value,
          backgroundColor: backgroundColor,
          color: color,
          valueColor: valueColor,
          semanticsLabel: semanticsLabel,
          semanticsValue: semanticsValue,
        );

  /// The animation duration for the progress.
  /// If animationDuration is null then it will use the default Duration(milliseconds: 500).
  final Duration? animationDuration;

  /// The width of the line used to draw the circle.
  final double strokeWidth;

  @override
  _AnimatedCircularProgressIndicatorState createState() =>
      _AnimatedCircularProgressIndicatorState();
}

class _AnimatedCircularProgressIndicatorState
    extends State<AnimatedCircularProgressIndicator>
    with TickerProviderStateMixin {
  AnimationController? _controller;
  Tween<double>? _tween;
  Animation<double>? _animation;

  void _setControllers() {
    _controller = AnimationController(
      duration: widget.animationDuration,
      vsync: this,
    );

    _tween = Tween(begin: widget.value, end: widget.value);
    _animation = _tween?.animate(
      CurvedAnimation(
        curve: Curves.easeInOut,
        parent: _controller!,
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    _setControllers();
  }

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
        animation: _animation!,
        builder: (context, child) {
          return CircularProgressIndicator(
            key: widget.key,
            value: _animation?.value,
            backgroundColor: widget.backgroundColor,
            color: widget.color,
            strokeWidth: widget.strokeWidth,
            valueColor: widget.valueColor,
            semanticsLabel: widget.semanticsLabel,
            semanticsValue: widget.semanticsValue,
          );
        });
  }

  @override
  void didUpdateWidget(AnimatedCircularProgressIndicator oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.animationDuration != widget.animationDuration) {
      //print("duration is changed remaking the controller and tween");
      _setControllers();
    }
    //print(" old value ${_tween?.begin }  new value ${oldWidget.value},old end ${_tween?.end},animationValue ${_animation?.value}");
    _tween?.begin = _animation?.value;
    _controller?.reset();
    _tween?.end = widget.value;
    _controller?.forward();
  }

  @override
  dispose() {
    _controller?.dispose(); // you need this
    super.dispose();
  }
}
